vollseg-napari-trackmate — VollSeg extension for cell tracking

Skip to main content
`Ctrl`+`K`

# vollseg-napari-trackmate

Track analysis using TrackMate xml and csv generated tracks using NapaTrackMater as the base library

This napari plugin was generated with Cookiecutter using @napari’s cookiecutter-napari-plugin template.

## Installation

You can install `vollseg-napari-trackmate` via pip:

    pip install vollseg-napari-trackmate

To install latest development version :

    pip install git+https://github.com/Kapoorlabs-CAPED/vollseg-napari-trackmate.git

## Contributing

Contributions are very welcome. Tests can be run with tox, please ensure the coverage at least stays the same before you submit a pull request.

## License

Distributed under the terms of the BSD-3 license, “vollseg-napari-trackmate” is free and open source software

## Issues

If you encounter any problems, please file an issue along with a detailed description.